<?php
/*
 * timeline.js.php
 * Description: JavaScript for the SIMILE Timline Plugin
 * Plugin URI: http://www.freshlabs.de/journal/archives/2006/10/wordpress-plugin-simile-timeline/
 * Author: Tim Isenheim
 * 
	===========================================================================
	SIMILE Timeline for WordPress
	Copyright (C) 2006 Tim Isenheim
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	===========================================================================
*/
include_once('../../../wp-blog-header.php');
header("Cache-Control: public");
header("Pragma: cache");

$offset = 60*60*24*60;
$ExpStr = "Expires: ".gmdate("D, d M Y H:i:s",time() + $offset)." GMT";
$LmStr = "Last-Modified: ".gmdate("D, d M Y H:i:s",filemtime(__FILE__))." GMT";

header($ExpStr);
header($LmStr);
header('Content-Type: text/javascript; charset: UTF-8');

$thisfile = $_SERVER['PHP_SELF'];
$thisfolder = substr($thisfile, 0, strpos($thisfile,'timeline.js'));

// Timeline orientation - still doesn't work from SIMILE side
if(get_option('stl_timelineorientation')){
	$orientation = get_option('stl_timelineorientation');	
} else $orientation = 0;

$ether_backgroundColors = get_option('stl_timeline_band_colors');
$stl_band_options = get_option('stl_timeline_band_options');

// default category and DOM-Id
$categories = '1';
$domid = "stl-mytimeline";

if(isset($_GET['cat'])){
	$categories = $_GET['cat'];
}else{
	$categories = get_option('stl_timelinecategories');
}

if(isset($_GET['id'])){
	$domid = $_GET['id'];
}

/* ---------------------------------------------------------------------------------
 * stl_createBandInfo
 * --------------------------------------------------------------------------------*/
function stl_createBandInfo($width,
						  $unit,
						  $interval,
						  $showEventText = true,
						  $trackHeight=false, 
						  $trackGap=false,
						  $eventSource = 'eventSource',
						  $theme = 'mytheme'
){
	
	$resolutions = array(
		1 => 'Timeline.DateTime.YEAR',
		2 => 'Timeline.DateTime.MONTH',
		3 => 'Timeline.DateTime.WEEK',		
		4 => 'Timeline.DateTime.DAY',
		5 => 'Timeline.DateTime.HOUR'
	);
	
	// switch option to display labels
	$showEventText = $showEventText == "on" ? "true" : "false";
	
	$hotzone_unit = $resolutions[$unit];
	$magnify = 1;

	echo "		Timeline.createHotZoneBandInfo({" . "\n";
	echo "			zones: [{
						start:	\"". stl_get_extreme_blog_date('MIN')."\",
						end:	\"". stl_get_extreme_blog_date('MAX')."\",
						unit: $hotzone_unit, 
						magnify: $magnify
					}]," . "\n";
	echo '			locale: \'' . get_option('stl_timeline_locale') . '\',' . "\n";
	echo '			showEventText:	' . $showEventText . ',' . "\n";
	
	if($trackHeight){
		echo '			trackHeight:	' . $trackHeight . ',' . "\n";
	}
	
	if($trackGap){
		echo '			trackGap:	' . $trackGap . ',' . "\n";
	}	
	echo '			eventSource:    ' . $eventSource . ',' . "\n";
	echo '			date:           "'; echo date('M d Y H:i:s');
	echo " GMT"  . date('O'); echo '",' . "\n";
	echo '			width:          "'.$width.'",' . "\n"; 
	echo '			intervalUnit:   '. $hotzone_unit . ',' . "\n"; 
	echo '			intervalPixels: ' . $interval .',' . "\n";
	echo '			theme:	mytheme' . "\n";
	echo '		})';
}
?>
/* WP SIMILE Timeline JavaScript configuration script
 * Plugin version: <?php echo $stl_timeline_plugin_version; ?>
 */
var tl;
function loadSimileTimeline() {
	
	if(document.getElementById("<?php echo $domid; ?>")){	
		
		// ### create custom theme
		var mytheme = Timeline.ClassicTheme.create();
		// ### style events
		mytheme.event.label.width = 200;
		mytheme.event.bubble.width = 320;
		mytheme.event.bubble.height = 160;
		
		mytheme.event.label.insideColor = '<?php echo $stl_band_options["labelinsidecolors"][0]; ?>';
		mytheme.event.label.outsideColor = '<?php echo $stl_band_options["labeloutsidecolors"][0]; ?>';
		mytheme.event.instant.icon = Timeline.urlPrefix + "images/gray-circle.png";
		// ### style ethers (bands)
		mytheme.ether.backgroundColors = ['<?php echo $stl_band_options["bgcolors"][0]; ?>',
						'<?php echo $stl_band_options["bgcolors"][1]; ?>',
						'<?php echo $stl_band_options["bgcolors"][2]; ?>',
						'<?php echo $stl_band_options["bgcolors"][3]; ?>'
										];
		mytheme.ether.interval.line.color = '<?php echo $stl_band_options["intvalinecolors"][0]; ?>';

		// ### duplicate theme and apply to lower band
		var mytheme_second = Timeline.ClassicTheme.create();
		mytheme_second = mytheme;
		mytheme_second.ether.interval.line.color = '<?php echo $stl_band_options["intvalinecolors"][1]; ?>';
		mytheme_second.event.label.insideColor = '<?php echo $stl_band_options["labelinsidecolors"][1]; ?>';
		mytheme_second.event.label.outsideColor = '<?php echo $stl_band_options["labeloutsidecolors"][1]; ?>';
		
		
		var eventSource = new Timeline.DefaultEventSource();
		
		var bandInfos = [
<?php stl_createBandInfo($stl_band_options['heights'][0], 
						$stl_band_options['units'][0],
						$stl_band_options['intervals'][0],
						$stl_band_options['showbandlabels'][0],
						false,
						false,
						'eventSource',
						'mytheme');
						echo ','; ?>

<?php stl_createBandInfo($stl_band_options['heights'][1],
						$stl_band_options['units'][1],
						$stl_band_options['intervals'][1],
						$stl_band_options['showbandlabels'][1],
						'0.5', '0.3',
						'eventSource',
						'mytheme_second'); ?>
	  ];

		bandInfos[1].syncWith = 0;
		bandInfos[1].highlight = true;
		bandInfos[1].eventPainter.setLayout(bandInfos[0].eventPainter.getLayout());

		tl = Timeline.create(document.getElementById("<?php echo $domid; ?>"), bandInfos, <?php echo $orientation; ?>);
		tl.loadXML("<?php echo $thisfolder; ?>timeline.xml.php?cat=<?php echo $categories; ?>",
			function(xml, url) {
				eventSource.loadXML(xml, url);
		});
  
  }else{ /* empty - do nothing when no timeline-frame is found */ }
}

var resizeTimerID = null;
function resizeSimileTimeline() {
    if (resizeTimerID == null) {
        resizeTimerID = window.setTimeout(function() {
            resizeTimerID = null;
            tl.layout();
        }, 500);
    }
}

/* addEvent function - by Scott Andrew 
 * http://www.scottandrew.com/weblog/articles/cbs-events
 */
function addEvent(obj, evType, fn){ 
	if (obj.addEventListener){ 
		obj.addEventListener(evType, fn, false); 
		return true; 
	} else if (obj.attachEvent){ 
		var r = obj.attachEvent("on"+evType, fn); 
		return r; 
	} else { 
		return false; 
	} 
}

// use cool onload observer if prototype.js is installed
if(Event.observe){
	Event.observe(window, "load", loadSimileTimeline);
	Event.observe(window, "resize", resizeSimileTimeline);
}
// otherwise fall back to non-standard addEvent
else{ 
	addEvent(window, "load", loadSimileTimeline);
	addEvent(window, "resize", resizeSimileTimeline);
}