<?php
/*
 * timeline.xml.php
 * Description: XML data for the SIMILE Timline Plugin. 
 * This file fetches the posts from the database and outputs them in the loop
 * Plugin URI: http://www.freshlabs.de/journal/archives/2006/10/wordpress-plugin-simile-timeline/
 * Author: Tim Isenheim
 * 
	===========================================================================
	SIMILE Timeline for WordPress
	Copyright (C) 2006 Tim Isenheim
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	===========================================================================
*/
include_once('../../../wp-blog-header.php');

/* =========================================================================
 * get post data
 * =========================================================================
 */
// get category IDs from Ajax post parameters
$cat = $_GET['cat']; 
// TODO: Sanitize query string. Allow numeric IDs and ',' only
$cat = js_escape($cat);

// RSS config
$rss_links = get_bookmarks("category=$cat");
// catch WordPress MU Installations
if(strstr($wp_version, 'wordpress-mu') === FALSE){
	require_once(ABSPATH . WPINC . '/rss-functions.php');
}else{
	require_once(ABSPATH . WPINC . '/rss.php');
}

// Get posts from the timeline categories
$poststatus = "publish";
if(get_option('stl_timeline_showfutureposts') == '1') $poststatus .= ",future";
query_posts("cat=$cat&post_status=$poststatus&showposts=-1");

/* =========================================================================
 * begin XML document
 * =========================================================================
 */
header('Content-type: text/xml; charset=UTF-8', true);
echo '<?xml version="1.0" encoding="UTF-8"?'.'>' . "\n\r";
echo '<data>' . "\n\r";

/* =========================================================================
 * BEGIN the LOOP for post data ********************************************
 * =========================================================================
 */
while (have_posts()) : the_post();

	$stl_icon = get_post_meta($post->ID, 'timeline_icon', true);
	$stl_image = get_post_meta($post->ID, 'timeline_image', true);

	echo '<event ';
	/* =========================================================================
	 * time information
	 * =========================================================================
	 */
	echo 'start="' . get_the_time('m d Y H:i:s') . " GMT" . date('O') . '"';
	
	// event has a duration if the end date is set for the current post
	if($post->stl_timeline_event_end != '0000-00-00 00:00:00' && $post->stl_timeline_event_end != null):
		echo ' end="' . stl_get_end_time('m d Y H:i:s') . " GMT" . date('O') .'"';
		echo ' isDuration="true"';
	endif;
	/* =========================================================================
	 * title information
	 * =========================================================================
	 */
	echo ' title="';
	the_title_rss();
	echo '"';
	/* =========================================================================
	 * link information
	 * =========================================================================
	 */
	if(get_post_meta($post->ID, 'timeline_link', true) != '') $titlelink = get_post_meta($post->ID, 'timeline_link', true);
	else $titlelink = get_permalink($post->ID);
	echo ' link="' . $titlelink . '"';
	/* =========================================================================
	 * category color
	 * =========================================================================
	 */
	$stl_term = stl_get_timeline_term_for_post($post->ID);

	echo ' color="'.$stl_term->color . '"';
	/* =========================================================================
	 * image/icon taken from custom field
	 * =========================================================================
	 */
	if($stl_icon != '') echo " icon=\"$stl_icon\"";
	if($stl_image != '') echo " image=\"$stl_image\"";
	echo ">\n\r";
	/* =========================================================================
	 * custom filtering for content. keep but encode html elements
	 * =========================================================================
	 */
	$the_content = $post->post_content;
	$the_content = htmlspecialchars($the_content);
	$the_content = ent2ncr($the_content);
	$the_content = wp_specialchars($the_content);
	echo $the_content;
	// =========================================================================
	echo '</event>';
	echo "\n\r";
endwhile;
/* =============================================================================
 * begin loop for RSS links ****************************************************
 * =============================================================================
 */
foreach($rss_links as $link){
	$feedContent = @fetch_rss($link->link_rss);
	$feedItems = $feedContent->items;
	$term = stl_get_term($link->term_id);
	if(!empty($feedItems)){
		foreach($feedItems as $feedItem){
			$date_published = $feedItem['pubdate'];
			if(isset($feedItem['published'])){
				$date_published = $feedItem['published'];
			}
			echo "<event";
			echo " start=\"" . date('m d Y H:i:s', strtotime($date_published)) . " GMT" . date('O') . "\"";
			echo " title=\"" . htmlspecialchars($feedItem['title']) . "\"";
			echo " link=\"" . $feedItem['link'] . "\"";
			echo " icon=\"" . $link->link_image . "\"";
			echo " color=\"" . $term->color . "\"";
			echo ">";
			$feed_content = htmlspecialchars($feedItem['summary']);
			echo $feed_content . "\n";
			echo "</event>" . "\n";
		}
	}
}
// =============================================================================
echo '</data>';
?>